@@ -205,6 +205,20 @@ class Server:
         self.mgdb[which].update_one(dict(email=email, host=host, role=role),
                                     {"$addToSet": {"dbs": db}}, upsert=True)
 
+    def get_ruler(self, token: str):
+        """Get the spec for which allow/deny rules this token's owner can set.
+
+        Args:
+            token (str): fetch token
+
+        Returns:
+            bool: The ruler doc if the owner can set rules, None o/w
+        """
+        email = self.email_from_fetch_token(token)
+        if email is None:
+            return None
+        return self.mgdb.rulers.find_one({"email": email})
+
     def can_grant(self, email: str, host: str, db: str, role: str):
         """Can the server grant credentials for role on host db to email owner?
 
@@ -365,18 +379,20 @@ class Server:
         if bulk_requests:
             self.mgdb.tokens.bulk_write(bulk_requests)
 
-    def email_from_fetch_token(self, token: str):
-        """Retrieve email given fetch token if not expired.
+    def email_from_fetch_token(self, token: str, expired_okay: bool = False):
+        """Retrieve email given fetch token.
 
         Args:
             token (str): fetch token
+            expired_okay (bool): return email address even if user's token is expired.
 
         Returns:
             str: email address if fetch token not expired, None o/w.
         """
+        when = datetime.min if expired_okay else datetime.utcnow()
         doc = self.mgdb.tokens.find_one({
             "fetch": {"$elemMatch": {"token": token,
-                                     "expires": {"$gte": datetime.utcnow()}}}
+                                     "expires": {"$gte": when}}}
         }, ["email"])
         if not doc:
             return None
